diff --git a/contrib/Makefile b/contrib/Makefile
--- a/contrib/Makefile
+++ b/contrib/Makefile
@@ -7,7 +7,7 @@
 all:
 	for i in $(DIRS); do (cd $$i && $(MAKE) $@); done
 install:
-	for i in $(DIRS); do (cd $$i && $(MAKE) LIB=$(LIB) $@); done
+	for i in $(DIRS); do (cd $$i && $(MAKE) LIB=$(LIB) BIN=$(BIN) $@); done
 source:
 	for i in $(DIRS); do (cd $$i && $(MAKE) $@); done
 clean:
diff --git a/contrib/conrado/Makefile b/contrib/conrado/Makefile
--- a/contrib/conrado/Makefile
+++ b/contrib/conrado/Makefile
@@ -6,8 +6,8 @@
 
 all: d2tex
 source: d2tex
-install:
-	cp d2tex $(LIB)/dijkstra.filter
+install: all
+	cp d2tex $(DESTDIR)$(LIB)/dijkstra.filter
 
 # TeX files.
 hospital.tex: hospital.nw d2tex
diff --git a/contrib/jobling/Makefile b/contrib/jobling/Makefile
--- a/contrib/jobling/Makefile
+++ b/contrib/jobling/Makefile
@@ -1,3 +1,5 @@
+BIN=/dev/null  # to be overridden
+LIB=/dev/null  # to be overridden
 PROG=correct-refs
 SCRIPTS=list-anchors.awk awk-scripts.awk
 
@@ -17,8 +19,8 @@
 	notangle -R$@ correct-refs.nw | cpif $@
 
 install: correct-refs.csh $(SCRIPTS)
-	cp correct-refs.csh $(HOME)/bin
-	cp $(SCRIPTS) $(HOME)/lib
+	cp correct-refs.csh $(DESTDIR)$(BIN)
+	cp $(SCRIPTS) $(DESTDIR)$(LIB)
 
 tidy:
 	rm -f *~ *% *.bak *.log *.blg
diff --git a/contrib/jonkrom/Makefile b/contrib/jonkrom/Makefile
--- a/contrib/jonkrom/Makefile
+++ b/contrib/jonkrom/Makefile
@@ -2,8 +2,8 @@
 SHELL=/bin/sh
 all: noxref.krom
 
-install:
-	cp noxref.krom $(LIB)
+install: all
+	cp noxref.krom $(DESTDIR)$(LIB)
 
 source: noxref.krom
 
diff --git a/contrib/kostas/Makefile b/contrib/kostas/Makefile
--- a/contrib/kostas/Makefile
+++ b/contrib/kostas/Makefile
@@ -1,6 +1,6 @@
 # Only works with Gnu make.
 
-LIB=/opt/noweb/lib
+LIB=/dev/null  # to be overridden
 ICONC=icont
 # This is supposed to be the defns.nw file in the icon directory of the distribution.
 defns=defns.nw
@@ -13,9 +13,9 @@
 all: C.filter C++.filter icon.filter oot.filter math.filter \
 	autodefs.oot autodefs.math
 
-install:
-	mv *.filter $(LIB)
-	mv autodefs.* $(LIB)
+install: all
+	cp *.filter $(DESTDIR)$(LIB)
+	cp autodefs.* $(DESTDIR)$(LIB)
 
 
 # TeX files.
diff --git a/contrib/norman/Makefile b/contrib/norman/Makefile
--- a/contrib/norman/Makefile
+++ b/contrib/norman/Makefile
@@ -4,7 +4,7 @@
 all:
 	for i in $(DIRS); do (cd $$i && $(MAKE) $@); done
 install:
-	for i in $(DIRS); do (cd $$i && $(MAKE) LIB=$(LIB) $@); done
+	for i in $(DIRS); do (cd $$i && $(MAKE) LIB=$(LIB) BIN=$(BIN) $@); done
 source:
 	for i in $(DIRS); do (cd $$i && $(MAKE) $@); done
 clean:
diff --git a/contrib/norman/numarkup/Makefile b/contrib/norman/numarkup/Makefile
--- a/contrib/norman/numarkup/Makefile
+++ b/contrib/norman/numarkup/Makefile
@@ -15,11 +15,9 @@
 	noweb -t numarkup.nw
 	$(MAKE) $(TARGET)
 
-install:
-	noweb -t numarkup.nw
-	$(MAKE) $(TARGET)
+install: all
 	strip $(TARGET)
-	cp $(TARGET) $(LIB)
+	cp $(TARGET) $(DESTDIR)$(LIB)
 
 source: main.c pass1.c latex.c input.c scraps.c names.c arena.c global.c
 
diff --git a/contrib/ydirson/Makefile b/contrib/ydirson/Makefile
--- a/contrib/ydirson/Makefile
+++ b/contrib/ydirson/Makefile
@@ -8,4 +8,4 @@
 clean:
 
 install:
-	cp -p $(FILTERS) $(LIB)
+	cp -p $(FILTERS) $(DESTDIR)$(LIB)
diff --git a/src/Makefile b/src/Makefile
--- a/src/Makefile
+++ b/src/Makefile
@@ -19,12 +19,13 @@
 # MAN7EXT is the extension for the nowebstyle man page (usually 7)
 # TEXINPUTS is the directory for TeX macro files
 # ELISP is the directory for emacs lisp files, or /dev/null not to install
-BIN=/usr/local/noweb
-LIB=/usr/local/noweb/lib
-MAN=/usr/local/noweb/man
+PREFIX=/usr/local
+BIN=$(PREFIX)/bin
+LIB=$(PREFIX)/libexec/noweb
+MAN=$(PREFIX)/share/man
 MANEXT=1
 MAN7EXT=7
-TEXINPUTS=/usr/local/tex/inputs
+TEXINPUTS=$(PREFIX)/tex/inputs
 ELISP=/dev/null
 
 # change WEAVE if you want a different version of noweave to be installed
@@ -38,8 +39,6 @@
 MAN7DIR=$(MAN)/man$(MAN7EXT)
 CATDIR=$(MAN)/cat$(MANEXT)
 CAT7DIR=$(MAN)/cat$(MAN7EXT)
-LIBNAME=$(LIB)
-TEXNAME=$(TEXINPUTS)
 
 all:
 	(cd c && $(MAKE) "CC=$(CC)" "CFLAGS=$(CFLAGS)" $@)
@@ -56,145 +55,144 @@
 
 install: install-code install-man install-tex install-elisp
 uninstall: uninstall-code uninstall-man uninstall-tex uninstall-elisp
-	rmdir $(BIN) $(LIB) 2>/dev/null || true
+	rmdir $(DESTDIR)$(BIN) $(DESTDIR)$(LIB) 2>/dev/null || true
 
 install-shell:
-	mkdir -p $(BIN) $(LIB)
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/noweb > $(BIN)/noweb
-	chmod +x $(BIN)/noweb
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/notangle > $(BIN)/notangle
-	chmod +x $(BIN)/notangle
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/$(WEAVE) > $(BIN)/$(WEAVE)
-	chmod +x $(BIN)/$(WEAVE)
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/nountangle > $(BIN)/nountangle
-	chmod +x $(BIN)/nountangle
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/nodefs > $(BIN)/nodefs
-	chmod +x $(BIN)/nodefs
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/noroots > $(BIN)/noroots
-	chmod +x $(BIN)/noroots
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/nuweb2noweb > $(BIN)/nuweb2noweb
-	chmod +x $(BIN)/nuweb2noweb
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/cpif > $(BIN)/cpif
-	chmod +x $(BIN)/cpif
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/htmltoc > $(BIN)/htmltoc
-	chmod +x $(BIN)/htmltoc
-	sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@" shell/noroff > $(BIN)/noroff
-	chmod +x $(BIN)/noroff
-	sed "s@|LIBDIR|@$(LIBNAME)@" shell/toroff > $(LIB)/toroff
-	chmod +x $(LIB)/toroff
-	cp shell/tmac.w $(LIB)
+	mkdir -p $(DESTDIR)$(BIN) $(DESTDIR)$(LIB)
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/noweb > $(DESTDIR)$(BIN)/noweb
+	chmod +x $(DESTDIR)$(BIN)/noweb
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/notangle > $(DESTDIR)$(BIN)/notangle
+	chmod +x $(DESTDIR)$(BIN)/notangle
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/$(WEAVE) > $(DESTDIR)$(BIN)/$(WEAVE)
+	chmod +x $(DESTDIR)$(BIN)/$(WEAVE)
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/nountangle > $(DESTDIR)$(BIN)/nountangle
+	chmod +x $(DESTDIR)$(BIN)/nountangle
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/nodefs > $(DESTDIR)$(BIN)/nodefs
+	chmod +x $(DESTDIR)$(BIN)/nodefs
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/noroots > $(DESTDIR)$(BIN)/noroots
+	chmod +x $(DESTDIR)$(BIN)/noroots
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/nuweb2noweb > $(DESTDIR)$(BIN)/nuweb2noweb
+	chmod +x $(DESTDIR)$(BIN)/nuweb2noweb
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/cpif > $(DESTDIR)$(BIN)/cpif
+	chmod +x $(DESTDIR)$(BIN)/cpif
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/htmltoc > $(DESTDIR)$(BIN)/htmltoc
+	chmod +x $(DESTDIR)$(BIN)/htmltoc
+	sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@" shell/noroff > $(DESTDIR)$(BIN)/noroff
+	chmod +x $(DESTDIR)$(BIN)/noroff
+	sed "s@|LIBDIR|@$(LIB)@" shell/toroff > $(DESTDIR)$(LIB)/toroff
+	chmod +x $(DESTDIR)$(LIB)/toroff
+	cp shell/tmac.w $(DESTDIR)$(LIB)
 
 uninstall-shell:
-	rm -f $(BIN)/noweb
-	rm -f $(BIN)/notangle
-	rm -f $(BIN)/$(WEAVE)
-	rm -f $(BIN)/nountangle
-	rm -f $(BIN)/nodefs
-	rm -f $(BIN)/noroots
-	rm -f $(BIN)/nuweb2noweb
-	rm -f $(BIN)/cpif
-	rm -f $(BIN)/htmltoc
-	rm -f $(BIN)/noroff
-	rm -f $(LIB)/toroff
-	rm -f $(LIB)/tmac.w
+	rm -f $(DESTDIR)$(BIN)/noweb
+	rm -f $(DESTDIR)$(BIN)/notangle
+	rm -f $(DESTDIR)$(BIN)/$(WEAVE)
+	rm -f $(DESTDIR)$(BIN)/nountangle
+	rm -f $(DESTDIR)$(BIN)/nodefs
+	rm -f $(DESTDIR)$(BIN)/noroots
+	rm -f $(DESTDIR)$(BIN)/nuweb2noweb
+	rm -f $(DESTDIR)$(BIN)/cpif
+	rm -f $(DESTDIR)$(BIN)/htmltoc
+	rm -f $(DESTDIR)$(BIN)/noroff
+	rm -f $(DESTDIR)$(LIB)/toroff
+	rm -f $(DESTDIR)$(LIB)/tmac.w
 
 install-code: install-shell
-	mkdir -p $(BIN) $(LIB)
+	mkdir -p $(DESTDIR)$(BIN) $(DESTDIR)$(LIB)
 	strip c/nt c/markup c/mnt c/finduses c/nwmktemp
-	cp c/nt c/markup c/mnt c/finduses c/nwmktemp $(LIB)
+	cp c/nt c/markup c/mnt c/finduses c/nwmktemp $(DESTDIR)$(LIB)
 	(cd $(LIBSRC) && $(MAKE) "ICONT=$(ICONT)" "ICONC=$(ICONC)" LIB=$(LIB) BIN=$(BIN) install)
 	(cd lib && $(MAKE) LIB=$(LIB) install)
 
 uninstall-code: uninstall-shell
-	rm -f $(LIB)/nt $(LIB)/markup $(LIB)/mnt $(LIB)/finduses
+	rm -f $(DESTDIR)$(LIB)/nt $(DESTDIR)$(LIB)/markup $(DESTDIR)$(LIB)/mnt $(DESTDIR)$(LIB)/finduses $(DESTDIR)$(LIB)/nwmktemp
 	(cd $(LIBSRC) && $(MAKE) "ICONT=$(ICONT)" "ICONC=$(ICONC)" LIB=$(LIB) BIN=$(BIN) uninstall)
 	(cd lib && $(MAKE) LIB=$(LIB) uninstall)
 install-man:
-	mkdir -p $(MANDIR) $(MAN7DIR)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.1 > $(MANDIR)/cpif.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.1 > $(MANDIR)/nodefs.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.1 > $(MANDIR)/noroots.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.1 > $(MANDIR)/noweb.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.1 > $(MANDIR)/noindex.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.1 > $(MANDIR)/nuweb2noweb.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.1 > $(MANDIR)/notangle.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.1 > $(MANDIR)/noroff.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.1 > $(MANDIR)/sl2h.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.1 > $(MANDIR)/htmltoc.$(MANEXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.7 > $(MAN7DIR)/nowebstyle.$(MAN7EXT)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.7 > $(MAN7DIR)/nowebfilters.$(MAN7EXT)
-	rm -f $(MANDIR)/noweave.$(MANEXT)
-	(cd $(MANDIR) && ln notangle.$(MANEXT) noweave.$(MANEXT))
-	rm -f $(MANDIR)/nountangle.$(MANEXT)
-	(cd $(MANDIR) && ln notangle.$(MANEXT) nountangle.$(MANEXT))
+	mkdir -p $(DESTDIR)$(MANDIR) $(DESTDIR)$(MAN7DIR)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/cpif.1 > $(DESTDIR)$(MANDIR)/cpif.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nodefs.1 > $(DESTDIR)$(MANDIR)/nodefs.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noroots.1 > $(DESTDIR)$(MANDIR)/noroots.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noweb.1 > $(DESTDIR)$(MANDIR)/noweb.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noindex.1 > $(DESTDIR)$(MANDIR)/noindex.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nuweb2noweb.1 > $(DESTDIR)$(MANDIR)/nuweb2noweb.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/notangle.1 > $(DESTDIR)$(MANDIR)/notangle.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noroff.1 > $(DESTDIR)$(MANDIR)/noroff.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/sl2h.1 > $(DESTDIR)$(MANDIR)/sl2h.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/htmltoc.1 > $(DESTDIR)$(MANDIR)/htmltoc.$(MANEXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nowebstyle.7 > $(DESTDIR)$(MAN7DIR)/nowebstyle.$(MAN7EXT)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nowebfilters.7 > $(DESTDIR)$(MAN7DIR)/nowebfilters.$(MAN7EXT)
+	rm -f $(DESTDIR)$(MANDIR)/noweave.$(MANEXT)
+	(cd $(DESTDIR)$(MANDIR) && ln -s notangle.$(MANEXT) noweave.$(MANEXT))
+	rm -f $(DESTDIR)$(MANDIR)/nountangle.$(MANEXT)
+	(cd $(DESTDIR)$(MANDIR) && ln -s notangle.$(MANEXT) nountangle.$(MANEXT))
 uninstall-man:
-	rm -f $(MANDIR)/cpif.$(MANEXT)
-	rm -f $(MANDIR)/nodefs.$(MANEXT)
-	rm -f $(MANDIR)/noroots.$(MANEXT)
-	rm -f $(MANDIR)/noweb.$(MANEXT)
-	rm -f $(MANDIR)/noindex.$(MANEXT)
-	rm -f $(MANDIR)/nuweb2noweb.$(MANEXT)
-	rm -f $(MANDIR)/notangle.$(MANEXT)
-	rm -f $(MANDIR)/noroff.$(MANEXT)
-	rm -f $(MANDIR)/sl2h.$(MANEXT)
-	rm -f $(MANDIR)/htmltoc.$(MANEXT)
-	rm -f $(MAN7DIR)/nowebstyle.$(MAN7EXT)
-	rm -f $(MAN7DIR)/nowebfilters.$(MAN7EXT)
-	rm -f $(MANDIR)/noweave.$(MANEXT)
-	rm -f $(MANDIR)/nountangle.$(MANEXT)
-	rmdir $(MANDIR) $(MAN7DIR) $(MAN) 2>/dev/null || true
+	rm -f $(DESTDIR)$(MANDIR)/cpif.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/nodefs.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/noroots.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/noweb.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/noindex.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/nuweb2noweb.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/notangle.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/noroff.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/sl2h.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/htmltoc.$(MANEXT)
+	rm -f $(DESTDIR)$(MAN7DIR)/nowebstyle.$(MAN7EXT)
+	rm -f $(DESTDIR)$(MAN7DIR)/nowebfilters.$(MAN7EXT)
+	rm -f $(DESTDIR)$(MANDIR)/noweave.$(MANEXT)
+	rm -f $(DESTDIR)$(MANDIR)/nountangle.$(MANEXT)
+	rmdir $(DESTDIR)$(MANDIR) $(DESTDIR)$(MAN7DIR) $(DESTDIR)$(MAN) 2>/dev/null || true
 install-gzipped-man:
-	mkdir -p $(MANDIR) $(MAN7DIR)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.1  | gzip -9 > $(MANDIR)/cpif.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.1  | gzip -9 > $(MANDIR)/nodefs.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.1  | gzip -9 > $(MANDIR)/noroots.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.1  | gzip -9 > $(MANDIR)/noweb.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.1  | gzip -9 > $(MANDIR)/noindex.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.1  | gzip -9 > $(MANDIR)/nuweb2noweb.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.1  | gzip -9 > $(MANDIR)/notangle.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.1  | gzip -9 > $(MANDIR)/noroff.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.1  | gzip -9 > $(MANDIR)/sl2h.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.1  | gzip -9 > $(MANDIR)/htmltoc.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.7  | gzip -9 > $(MAN7DIR)/nowebstyle.$(MAN7EXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.7  | gzip -9 > $(MAN7DIR)/nowebfilters.$(MAN7EXT).gz
-	rm -f $(MANDIR)/noweave.$(MANEXT).gz
-	(cd $(MANDIR) && ln notangle.$(MANEXT).gz noweave.$(MANEXT).gz)
-	rm -f $(MANDIR)/nountangle.$(MANEXT).gz
-	(cd $(MANDIR) && ln notangle.$(MANEXT).gz nountangle.$(MANEXT).gz)
+	mkdir -p $(DESTDIR)$(MANDIR) $(DESTDIR)$(MAN7DIR)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/cpif.1  | gzip -9 > $(DESTDIR)$(MANDIR)/cpif.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nodefs.1  | gzip -9 > $(DESTDIR)$(MANDIR)/nodefs.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noroots.1  | gzip -9 > $(DESTDIR)$(MANDIR)/noroots.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noweb.1  | gzip -9 > $(DESTDIR)$(MANDIR)/noweb.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noindex.1  | gzip -9 > $(DESTDIR)$(MANDIR)/noindex.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nuweb2noweb.1  | gzip -9 > $(DESTDIR)$(MANDIR)/nuweb2noweb.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/notangle.1  | gzip -9 > $(DESTDIR)$(MANDIR)/notangle.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noroff.1  | gzip -9 > $(DESTDIR)$(MANDIR)/noroff.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/sl2h.1  | gzip -9 > $(DESTDIR)$(MANDIR)/sl2h.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/htmltoc.1  | gzip -9 > $(DESTDIR)$(MANDIR)/htmltoc.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nowebstyle.7  | gzip -9 > $(DESTDIR)$(MAN7DIR)/nowebstyle.$(MAN7EXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nowebfilters.7  | gzip -9 > $(DESTDIR)$(MAN7DIR)/nowebfilters.$(MAN7EXT).gz
+	rm -f $(DESTDIR)$(MANDIR)/noweave.$(MANEXT).gz
+	(cd $(DESTDIR)$(MANDIR) && ln -s notangle.$(MANEXT).gz noweave.$(MANEXT).gz)
+	rm -f $(DESTDIR)$(MANDIR)/nountangle.$(MANEXT).gz
+	(cd $(DESTDIR)$(MANDIR) && ln -s notangle.$(MANEXT).gz nountangle.$(MANEXT).gz)
 install-preformat-man:
 	-echo "Warning: install-preformat-man is obsolete, even on Slackware systems" 1>&2
-	mkdir -p $(CATDIR) $(CAT7DIR)
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/cpif.txt  | gzip > $(CATDIR)/cpif.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nodefs.txt  | gzip > $(CATDIR)/nodefs.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroots.txt  | gzip > $(CATDIR)/noroots.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noweb.txt  | gzip > $(CATDIR)/noweb.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noindex.txt  | gzip > $(CATDIR)/noindex.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nuweb2noweb.txt  | gzip > $(CATDIR)/nuweb2noweb.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/notangle.txt  | gzip > $(CATDIR)/notangle.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/noroff.txt  | gzip > $(CATDIR)/noroff.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/sl2h.txt  | gzip > $(CATDIR)/sl2h.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/htmltoc.txt  | gzip > $(CATDIR)/htmltoc.$(MANEXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebstyle.txt  | gzip > $(CAT7DIR)/nowebstyle.$(MAN7EXT).gz
-	sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@" xdoc/nowebfilters.txt  | gzip > $(CAT7DIR)/nowebfilters.$(MAN7EXT).gz
-	rm -f $(CATDIR)/noweave.$(MANEXT).gz
-	(cd $(CATDIR) && ln notangle.$(MANEXT).gz noweave.$(MANEXT).gz)
-	rm -f $(CATDIR)/nountangle.$(MANEXT).gz
-	(cd $(CATDIR) && ln notangle.$(MANEXT).gz nountangle.$(MANEXT).gz)
+	mkdir -p $(DESTDIR)$(CATDIR) $(DESTDIR)$(CAT7DIR)
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/cpif.txt  | gzip > $(DESTDIR)$(CATDIR)/cpif.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nodefs.txt  | gzip > $(DESTDIR)$(CATDIR)/nodefs.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noroots.txt  | gzip > $(DESTDIR)$(CATDIR)/noroots.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noweb.txt  | gzip > $(DESTDIR)$(CATDIR)/noweb.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noindex.txt  | gzip > $(DESTDIR)$(CATDIR)/noindex.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nuweb2noweb.txt  | gzip > $(DESTDIR)$(CATDIR)/nuweb2noweb.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/notangle.txt  | gzip > $(DESTDIR)$(CATDIR)/notangle.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/noroff.txt  | gzip > $(DESTDIR)$(CATDIR)/noroff.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/sl2h.txt  | gzip > $(DESTDIR)$(CATDIR)/sl2h.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/htmltoc.txt  | gzip > $(DESTDIR)$(CATDIR)/htmltoc.$(MANEXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nowebstyle.txt  | gzip > $(DESTDIR)$(CAT7DIR)/nowebstyle.$(MAN7EXT).gz
+	sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@" xdoc/nowebfilters.txt  | gzip > $(DESTDIR)$(CAT7DIR)/nowebfilters.$(MAN7EXT).gz
+	rm -f $(DESTDIR)$(CATDIR)/noweave.$(MANEXT).gz
+	(cd $(DESTDIR)$(CATDIR) && ln -s notangle.$(MANEXT).gz noweave.$(MANEXT).gz)
+	rm -f $(DESTDIR)$(CATDIR)/nountangle.$(MANEXT).gz
+	(cd $(DESTDIR)$(CATDIR) && ln -s notangle.$(MANEXT).gz nountangle.$(MANEXT).gz)
 install-tex:
-	mkdir -p $(TEXINPUTS)
-	sed "s@|GITVERSION|@$(GITVERSION)@" tex/nwmac.tex > $(TEXINPUTS)/nwmac.tex
-	sed "s@|GITVERSION|@$(GITVERSION)@" tex/noweb.sty > $(TEXINPUTS)/noweb.sty
+	mkdir -p $(DESTDIR)$(TEXINPUTS)
+	sed "s@|GITVERSION|@$(GITVERSION)@" tex/nwmac.tex > $(DESTDIR)$(TEXINPUTS)/nwmac.tex
+	sed "s@|GITVERSION|@$(GITVERSION)@" tex/noweb.sty > $(DESTDIR)$(TEXINPUTS)/noweb.sty
 	-texhash || echo "Program texhash not found or failed"
 
 uninstall-tex:
-	rm -f $(TEXINPUTS)/nwmac.tex
-	rm -f $(TEXINPUTS)/noweb.sty
+	rm -f $(DESTDIR)$(TEXINPUTS)/nwmac.tex
+	rm -f $(DESTDIR)$(TEXINPUTS)/noweb.sty
 install-elisp:
-	if [ "/dev/null" != "$(ELISP)" ]; then mkdir -p $(ELISP); fi
-	cp elisp/noweb-mode.el $(ELISP)
+	if [ "/dev/null" != "$(ELISP)" ]; then mkdir -p $(DESTDIR)$(ELISP) && cp elisp/noweb-mode.el $(DESTDIR)$(ELISP); fi
 
 uninstall-elisp:
-	rm -f $(ELISP)/noweb-mode.el
+	if [ "/dev/null" != "$(ELISP)" ]; then rm -f $(DESTDIR)$(ELISP)/noweb-mode.el; fi
 source: FAQ
 	for i in c shell lib xdoc icon awk tex; do (cd $$i && $(MAKE) CPIF=">" $@); done
 	sleep 1
diff --git a/src/Makefile.nw b/src/Makefile.nw
--- a/src/Makefile.nw
+++ b/src/Makefile.nw
@@ -24,12 +24,13 @@
 # MAN7EXT is the extension for the nowebstyle man page (usually 7)
 # TEXINPUTS is the directory for TeX macro files
 # ELISP is the directory for emacs lisp files, or /dev/null not to install
-BIN=/usr/local/noweb
-LIB=/usr/local/noweb/lib
-MAN=/usr/local/noweb/man
+PREFIX=/usr/local
+BIN=$(PREFIX)/bin
+LIB=$(PREFIX)/libexec/noweb
+MAN=$(PREFIX)/share/man
 MANEXT=1
 MAN7EXT=7
-TEXINPUTS=/usr/local/tex/inputs
+TEXINPUTS=$(PREFIX)/tex/inputs
 ELISP=/dev/null
 
 # change WEAVE if you want a different version of noweave to be installed
@@ -43,8 +44,6 @@
 MAN7DIR=$(MAN)/man$(MAN7EXT)
 CATDIR=$(MAN)/cat$(MANEXT)
 CAT7DIR=$(MAN)/cat$(MAN7EXT)
-LIBNAME=$(LIB)
-TEXNAME=$(TEXINPUTS)
 
 all:
 	(cd c && $(MAKE) "CC=$(CC)" "CFLAGS=$(CFLAGS)" $@)
@@ -61,26 +60,26 @@
 
 install: install-code install-man install-tex install-elisp
 uninstall: uninstall-code uninstall-man uninstall-tex uninstall-elisp
-	rmdir $(BIN) $(LIB) 2>/dev/null || true
+	rmdir $(DESTDIR)$(BIN) $(DESTDIR)$(LIB) 2>/dev/null || true
 
 install-shell:
-	mkdir -p $(BIN) $(LIB)
+	mkdir -p $(DESTDIR)$(BIN) $(DESTDIR)$(LIB)
 	<<shell binaries>>
-	cp shell/tmac.w $(LIB)
+	cp shell/tmac.w $(DESTDIR)$(LIB)
 
 uninstall-shell:
 	<<uninstall shell binaries>>
-	rm -f $(LIB)/tmac.w
+	rm -f $(DESTDIR)$(LIB)/tmac.w
 
 install-code: install-shell
-	mkdir -p $(BIN) $(LIB)
+	mkdir -p $(DESTDIR)$(BIN) $(DESTDIR)$(LIB)
 	strip c/nt c/markup c/mnt c/finduses c/nwmktemp
-	cp c/nt c/markup c/mnt c/finduses c/nwmktemp $(LIB)
+	cp c/nt c/markup c/mnt c/finduses c/nwmktemp $(DESTDIR)$(LIB)
 	(cd $(LIBSRC) && $(MAKE) "ICONT=$(ICONT)" "ICONC=$(ICONC)" LIB=$(LIB) BIN=$(BIN) install)
 	(cd lib && $(MAKE) LIB=$(LIB) install)
 
 uninstall-code: uninstall-shell
-	rm -f $(LIB)/nt $(LIB)/markup $(LIB)/mnt $(LIB)/finduses
+	rm -f $(DESTDIR)$(LIB)/nt $(DESTDIR)$(LIB)/markup $(DESTDIR)$(LIB)/mnt $(DESTDIR)$(LIB)/finduses $(DESTDIR)$(LIB)/nwmktemp
 	(cd $(LIBSRC) && $(MAKE) "ICONT=$(ICONT)" "ICONC=$(ICONC)" LIB=$(LIB) BIN=$(BIN) uninstall)
 	(cd lib && $(MAKE) LIB=$(LIB) uninstall)
 @ I do the [[<<shell binaries>>]] before [[$(LIBSRC)]] so that the
@@ -92,37 +91,37 @@
 	 noroff
 do
   echo '@<<shell binaries@>>='
-  echo 'sed "s@|LIBDIR|@$(LIBNAME)@;s@|GITVERSION|@$(GITVERSION)@"' "shell/$i" '> $(BIN)/'"$i"
-  echo 'chmod +x $(BIN)/'"$i"
+  echo 'sed "s@|LIBDIR|@$(LIB)@;s@|GITVERSION|@$(GITVERSION)@"' "shell/$i" '> $(DESTDIR)$(BIN)/'"$i"
+  echo 'chmod +x $(DESTDIR)$(BIN)/'"$i"
   echo '@<<uninstall shell binaries@>>='
-  echo 'rm -f $(BIN)/'"$i"
+  echo 'rm -f $(DESTDIR)$(BIN)/'"$i"
 done
 for i in toroff
 do
   echo '@<<shell binaries@>>='
-  echo 'sed "s@|LIBDIR|@$(LIBNAME)@"' "shell/$i" '> $(LIB)/'"$i"
-  echo 'chmod +x $(LIB)/'"$i"
+  echo 'sed "s@|LIBDIR|@$(LIB)@"' "shell/$i" '> $(DESTDIR)$(LIB)/'"$i"
+  echo 'chmod +x $(DESTDIR)$(LIB)/'"$i"
   echo '@<<uninstall shell binaries@>>='
-  echo 'rm -f $(LIB)/'"$i"
+  echo 'rm -f $(DESTDIR)$(LIB)/'"$i"
 done
 <<*>>=
 install-man:
-	mkdir -p $(MANDIR) $(MAN7DIR)
+	mkdir -p $(DESTDIR)$(MANDIR) $(DESTDIR)$(MAN7DIR)
 	<<ordinary pages>>
 uninstall-man:
 	<<uninstall ordinary pages>>
-	rmdir $(MANDIR) $(MAN7DIR) $(MAN) 2>/dev/null || true
+	rmdir $(DESTDIR)$(MANDIR) $(DESTDIR)$(MAN7DIR) $(DESTDIR)$(MAN) 2>/dev/null || true
 @
 Slackware no longer uses preformatted compressed pages, just
 compressed pages.
 <<*>>=
 install-gzipped-man:
-	mkdir -p $(MANDIR) $(MAN7DIR)
+	mkdir -p $(DESTDIR)$(MANDIR) $(DESTDIR)$(MAN7DIR)
 	<<compressed pages>>
 <<*>>=
 install-preformat-man:
 	-echo "Warning: install-preformat-man is obsolete, even on Slackware systems" 1>&2
-	mkdir -p $(CATDIR) $(CAT7DIR)
+	mkdir -p $(DESTDIR)$(CATDIR) $(DESTDIR)$(CAT7DIR)
 	<<preformatted compressed pages>>
 <<generate chunks>>=
 NORMALPAGES="cpif nodefs noroots noweb noindex nuweb2noweb notangle noroff sl2h htmltoc"
@@ -132,61 +131,61 @@
 
 for i in $NORMALPAGES; do
   echo '@<<ordinary pages@>>='
-  echo 'sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@"' \
-	"xdoc/$i.1" '> $(MANDIR)/'"$i"'.$(MANEXT)'
+  echo 'sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@"' \
+	"xdoc/$i.1" '> $(DESTDIR)$(MANDIR)/'"$i"'.$(MANEXT)'
   echo '@<<uninstall ordinary pages@>>='
-  echo 'rm -f $(MANDIR)/'"$i"'.$(MANEXT)'
+  echo 'rm -f $(DESTDIR)$(MANDIR)/'"$i"'.$(MANEXT)'
 done
 for i in $NORMAL7PAGES; do
   echo '@<<ordinary pages@>>='
-  echo 'sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@"' \
-	"xdoc/$i.7" '> $(MAN7DIR)/'"$i"'.$(MAN7EXT)'
+  echo 'sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@"' \
+	"xdoc/$i.7" '> $(DESTDIR)$(MAN7DIR)/'"$i"'.$(MAN7EXT)'
   echo '@<<uninstall ordinary pages@>>='
-  echo 'rm -f $(MAN7DIR)/'"$i"'.$(MAN7EXT)'
+  echo 'rm -f $(DESTDIR)$(MAN7DIR)/'"$i"'.$(MAN7EXT)'
 done
 
 for i in $LINKPAGES; do
   echo '@<<ordinary pages@>>='
-  echo 'rm -f $(MANDIR)/'"$i"'.$(MANEXT)'
-  echo '(cd $(MANDIR) && ln notangle.$(MANEXT)' "$i"'.$(MANEXT))'
+  echo 'rm -f $(DESTDIR)$(MANDIR)/'"$i"'.$(MANEXT)'
+  echo '(cd $(DESTDIR)$(MANDIR) && ln -s notangle.$(MANEXT)' "$i"'.$(MANEXT))'
   echo '@<<uninstall ordinary pages@>>='
-  echo 'rm -f $(MANDIR)/'"$i"'.$(MANEXT)'
+  echo 'rm -f $(DESTDIR)$(MANDIR)/'"$i"'.$(MANEXT)'
 done
 
 echo '@<<compressed pages@>>='
 
 for i in $NORMALPAGES; do
-  echo 'sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@"' \
-	"xdoc/$i.1" ' | gzip -9 > $(MANDIR)/'"$i"'.$(MANEXT).gz'
+  echo 'sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@"' \
+	"xdoc/$i.1" ' | gzip -9 > $(DESTDIR)$(MANDIR)/'"$i"'.$(MANEXT).gz'
 done
 for i in $NORMAL7PAGES; do
-  echo 'sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@"' \
-	"xdoc/$i.7" ' | gzip -9 > $(MAN7DIR)/'"$i"'.$(MAN7EXT).gz'
+  echo 'sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@"' \
+	"xdoc/$i.7" ' | gzip -9 > $(DESTDIR)$(MAN7DIR)/'"$i"'.$(MAN7EXT).gz'
 done
 
 for i in $LINKPAGES; do
-  echo 'rm -f $(MANDIR)/'"$i"'.$(MANEXT).gz'
-  echo '(cd $(MANDIR) && ln notangle.$(MANEXT).gz' "$i"'.$(MANEXT).gz)'
+  echo 'rm -f $(DESTDIR)$(MANDIR)/'"$i"'.$(MANEXT).gz'
+  echo '(cd $(DESTDIR)$(MANDIR) && ln -s notangle.$(MANEXT).gz' "$i"'.$(MANEXT).gz)'
 done
 
 echo '@<<preformatted compressed pages@>>='
 
 for i in $NORMALPAGES; do
-  echo 'sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@"' \
-	"xdoc/$i.txt" ' | gzip > $(CATDIR)/'"$i"'.$(MANEXT).gz'
+  echo 'sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@"' \
+	"xdoc/$i.txt" ' | gzip > $(DESTDIR)$(CATDIR)/'"$i"'.$(MANEXT).gz'
 done
 for i in $NORMAL7PAGES; do
-  echo 'sed -e "s@|LIBDIR|@$(LIBNAME)@" -e "s@|TEXINPUTS|@$(TEXNAME)@"' \
-	"xdoc/$i.txt" ' | gzip > $(CAT7DIR)/'"$i"'.$(MAN7EXT).gz'
+  echo 'sed -e "s@|LIBDIR|@$(LIB)@" -e "s@|TEXINPUTS|@$(TEXINPUTS)@"' \
+	"xdoc/$i.txt" ' | gzip > $(DESTDIR)$(CAT7DIR)/'"$i"'.$(MAN7EXT).gz'
 done
 
 for i in $LINKPAGES; do
-  echo 'rm -f $(CATDIR)/'"$i"'.$(MANEXT).gz'
-  echo '(cd $(CATDIR) && ln notangle.$(MANEXT).gz' "$i"'.$(MANEXT).gz)'
+  echo 'rm -f $(DESTDIR)$(CATDIR)/'"$i"'.$(MANEXT).gz'
+  echo '(cd $(DESTDIR)$(CATDIR) && ln -s notangle.$(MANEXT).gz' "$i"'.$(MANEXT).gz)'
 done
 <<*>>=
 install-tex:
-	mkdir -p $(TEXINPUTS)
+	mkdir -p $(DESTDIR)$(TEXINPUTS)
 	<<tex installation>>
 	-texhash || echo "Program texhash not found or failed"
 
@@ -196,17 +195,16 @@
 for i in nwmac.tex noweb.sty
 do
   echo '@<<tex installation@>>='
-  echo 'sed "s@|GITVERSION|@$(GITVERSION)@"' "tex/$i" '> $(TEXINPUTS)/'"$i"
+  echo 'sed "s@|GITVERSION|@$(GITVERSION)@"' "tex/$i" '> $(DESTDIR)$(TEXINPUTS)/'"$i"
   echo '@<<tex uninstallation@>>='
-  echo 'rm -f $(TEXINPUTS)/'"$i"
+  echo 'rm -f $(DESTDIR)$(TEXINPUTS)/'"$i"
 done
 <<*>>=
 install-elisp:
-	if [ "/dev/null" != "$(ELISP)" ]; then mkdir -p $(ELISP); fi
-	cp elisp/noweb-mode.el $(ELISP)
+	if [ "/dev/null" != "$(ELISP)" ]; then mkdir -p $(DESTDIR)$(ELISP) && cp elisp/noweb-mode.el $(DESTDIR)$(ELISP); fi
 
 uninstall-elisp:
-	rm -f $(ELISP)/noweb-mode.el
+	if [ "/dev/null" != "$(ELISP)" ]; then rm -f $(DESTDIR)$(ELISP)/noweb-mode.el; fi
 @
 <<*>>=
 source: FAQ
diff --git a/src/awk/Makefile b/src/awk/Makefile
--- a/src/awk/Makefile
+++ b/src/awk/Makefile
@@ -19,13 +19,13 @@
 	touch $(EXECS)
 
 install: all
-	cp $(LIBEXECSBARE) $(LIB)
-	for i in $(LIBEXECSDEP); do sed "s@|LIBDIR|@$(LIB)@" "$$i" > $(LIB)/"$$i"; chmod +x $(LIB)/$$i; done
-	cp $(BINEXECS) $(BIN)
+	cp $(LIBEXECSBARE) $(DESTDIR)$(LIB)
+	for i in $(LIBEXECSDEP); do sed "s@|LIBDIR|@$(LIB)@" "$$i" > $(DESTDIR)$(LIB)/"$$i"; chmod +x $(DESTDIR)$(LIB)/$$i; done
+	cp $(BINEXECS) $(DESTDIR)$(BIN)
 
 uninstall:
-	for i in $(LIBEXECS); do rm -f $(LIB)/$$i; done
-	for i in $(BINEXECS); do rm -f $(BIN)/$$i; done
+	for i in $(LIBEXECS); do rm -f $(DESTDIR)$(LIB)/$$i; done
+	for i in $(BINEXECS); do rm -f $(DESTDIR)$(BIN)/$$i; done
 
 source: $(EXECS)
 
diff --git a/src/icon/Makefile b/src/icon/Makefile
--- a/src/icon/Makefile
+++ b/src/icon/Makefile
@@ -34,15 +34,15 @@
 boot:
 	touch $(SRCS)
 
-install: $(EXECS)
-	cp $(LIBEXECS) $(LIB)
-	cp $(BINEXECS) $(BIN)
-	cp $(LIBSPECIAL) $(LIB)/autodefs.c
+install: all
+	cp $(LIBEXECS) $(DESTDIR)$(LIB)
+	cp $(BINEXECS) $(DESTDIR)$(BIN)
+	cp $(LIBSPECIAL) $(DESTDIR)$(LIB)/autodefs.c
 
 uninstall:
-	for i in $(LIBEXECS); do rm -f $(LIB)/$$i; done
-	for i in $(BINEXECS); do rm -f $(BIN)/$$i; done
-	rm -f $(LIB)/autodefs.c
+	for i in $(LIBEXECS); do rm -f $(DESTDIR)$(LIB)/$$i; done
+	for i in $(BINEXECS); do rm -f $(DESTDIR)$(BIN)/$$i; done
+	rm -f $(DESTDIR)$(LIB)/autodefs.c
 
 clean:
 	rm -f *.tex *.dvi *.aux *.log *.blg *.bbl *~ *.toc *.html *.u1 *.u2
diff --git a/src/lib/Makefile b/src/lib/Makefile
--- a/src/lib/Makefile
+++ b/src/lib/Makefile
@@ -11,15 +11,14 @@
 	chmod +x unmarkup emptydefn toascii nwmtime pipedocs h2a btdefn
 
 install: all
-	cp unmarkup emptydefn nwmtime btdefn $(LIB)
-	sed 's@|LIBDIR|@$(LIB)@g' pipedocs > $(LIB)/pipedocs
-	sed 's@|LIBDIR|@$(LIB)@g' toascii > $(LIB)/toascii
-	sed 's@|LIBDIR|@$(LIB)@g' h2a > $(LIB)/h2a
-	chmod +x $(LIB)/pipedocs $(LIB)/toascii $(LIB)/h2a
+	cp unmarkup emptydefn nwmtime btdefn $(DESTDIR)$(LIB)
+	sed 's@|LIBDIR|@$(LIB)@g' pipedocs > $(DESTDIR)$(LIB)/pipedocs
+	sed 's@|LIBDIR|@$(LIB)@g' toascii > $(DESTDIR)$(LIB)/toascii
+	sed 's@|LIBDIR|@$(LIB)@g' h2a > $(DESTDIR)$(LIB)/h2a
+	chmod +x $(DESTDIR)$(LIB)/pipedocs $(DESTDIR)$(LIB)/toascii $(DESTDIR)$(LIB)/h2a
 
 uninstall:
-	for i in unmarkup emptydefn toascii nwmtime h2a btdefn; do rm -f $(LIB)/$$i; done
-	rm -f $(LIB)/pipedocs
+	for i in unmarkup emptydefn toascii nwmtime pipedocs h2a btdefn; do rm -f $(DESTDIR)$(LIB)/$$i; done
 
 source: toascii
 touch: toascii
diff --git a/src/shell/Makefile b/src/shell/Makefile
--- a/src/shell/Makefile
+++ b/src/shell/Makefile
@@ -1,7 +1,6 @@
 # Copyright 1993 by Norman Ramsey.  All rights reserved.
 # See file COPYRIGHT for more information.
 SHELL=/bin/sh
-LIB=/usr/public/pkg/noweb/lib
 
 EXEC=noweave noweb notangle noroff toroff
 SRCS=$(EXEC) tmac.w
diff --git a/src/xdoc/Makefile b/src/xdoc/Makefile
--- a/src/xdoc/Makefile
+++ b/src/xdoc/Makefile
@@ -33,13 +33,13 @@
 www: $(WWW)/onepage.ps $(WWW)/guide.ps $(WWW)/guide.html
 
 $(WWW)/onepage.ps: onepage.ps
-	cp onepage.ps $(WWW)
+	cp onepage.ps $@
 
 $(WWW)/guide.ps: guide.ps
-	cp guide.ps $(WWW)
+	cp guide.ps $@
 
 $(WWW)/guide.html: guide.html
-	cp guide.html $(WWW)
+	cp guide.html $@
 
 notangle.1: manpage.nw ../shell/noweave.nw docdate.nw
 	notangle -t8 -R$@ manpage.nw ../shell/noweave.nw docdate.nw | $(DOVERSION) > $@
